# v0.0.6
- Less noisy Relaxer by default.


# v0.0.4
- Fix model download 
- More documentation
- Bug fixes

# v0.0.2
- Fix edge cases for triple bonds
- Enable model weights download within code

# v0.0.1

- Initial release.